parade.template.workspace package
=================================

Module contents
---------------

.. automodule:: parade.template.workspace
    :members:
    :undoc-members:
    :show-inheritance:
